@@ -30,7 +30,7 @@ use std::process::exit;
 use nu_ansi_term::{AnsiStrings as ANSIStrings, Style};
 
 use crate::fs::feature::git::GitCache;
-use crate::fs::filter::GitIgnore;
+use crate::fs::filter::{FileFilterFlags::OnlyFiles, GitIgnore};
 use crate::fs::{Dir, File};
 use crate::options::stdin::FilesInput;
 use crate::options::{vars, Options, OptionsResult, Vars};
@@ -343,8 +343,10 @@ impl<'args> Exa<'args> {
                     Err((path, e)) => writeln!(io::stderr(), "[{}: {}]", path.display(), e)?,
                 }
             }
-
-            self.options.filter.filter_child_files(&mut children);
+            let recursing = self.options.dir_action.recurse_options().is_some();
+            self.options
+                .filter
+                .filter_child_files(recursing, &mut children);
             self.options.filter.sort_files(&mut children);
 
             if let Some(recurse_opts) = self.options.dir_action.recurse_options() {
@@ -384,11 +386,18 @@ impl<'args> Exa<'args> {
     }
 
     /// Prints the list of files using whichever view is selected.
-    fn print_files(&mut self, dir: Option<&Dir>, files: Vec<File<'_>>) -> io::Result<()> {
+    fn print_files(&mut self, dir: Option<&Dir>, mut files: Vec<File<'_>>) -> io::Result<()> {
         if files.is_empty() {
             return Ok(());
         }
-
+        let recursing = self.options.dir_action.recurse_options().is_some();
+        let only_files = self.options.filter.flags.contains(&OnlyFiles);
+        if recursing && only_files {
+            files = files
+                .into_iter()
+                .filter(|f| !f.is_directory())
+                .collect::<Vec<_>>();
+        }
         let theme = &self.theme;
         let View {
             ref mode,
