@@ -1,11 +1,16 @@
 use crate::options::parser::MatchedFlags;
 use crate::options::{flags, vars, OptionsError, Vars};
-use crate::theme::{ColourScale, Definitions, Options, UseColours};
+use crate::output::color_scale::ColorScaleOptions;
+use crate::theme::{Definitions, Options, UseColours};
+use std::path::PathBuf;
+
+use super::config::ThemeConfig;
 
 impl Options {
     pub fn deduce<V: Vars>(matches: &MatchedFlags<'_>, vars: &V) -> Result<Self, OptionsError> {
         let use_colours = UseColours::deduce(matches, vars)?;
-        let colour_scale = ColourScale::deduce(matches)?;
+        let colour_scale = ColorScaleOptions::deduce(matches, vars)?;
+        let theme_config = ThemeConfig::deduce(vars);
 
         let definitions = if use_colours == UseColours::Never {
             Definitions::default()
@@ -17,10 +22,33 @@ impl Options {
             use_colours,
             colour_scale,
             definitions,
+            theme_config,
         })
     }
 }
 
+impl ThemeConfig {
+    fn deduce<V: Vars>(vars: &V) -> Option<Self> {
+        if let Some(path) = vars.get("EZA_CONFIG_DIR") {
+            let path = PathBuf::from(path);
+            let path = path.join("theme.yml");
+            if path.exists() {
+                Some(ThemeConfig::from_path(&path.to_string_lossy()))
+            } else {
+                None
+            }
+        } else {
+            let path = dirs::config_dir().unwrap_or_default();
+            let path = path.join("eza").join("theme.yml");
+            if path.exists() {
+                Some(ThemeConfig::default())
+            } else {
+                None
+            }
+        }
+    }
+}
+
 impl UseColours {
     fn deduce<V: Vars>(matches: &MatchedFlags<'_>, vars: &V) -> Result<Self, OptionsError> {
         let default_value = match vars.get(vars::NO_COLOR) {
@@ -46,19 +74,6 @@ impl UseColours {
     }
 }
 
-impl ColourScale {
-    fn deduce(matches: &MatchedFlags<'_>) -> Result<Self, OptionsError> {
-        if matches
-            .has_where(|f| f.matches(&flags::COLOR_SCALE) || f.matches(&flags::COLOUR_SCALE))?
-            .is_some()
-        {
-            Ok(Self::Gradient)
-        } else {
-            Ok(Self::Fixed)
-        }
-    }
-}
-
 impl Definitions {
     fn deduce<V: Vars>(vars: &V) -> Self {
         let ls = vars
@@ -88,6 +103,7 @@ mod terminal_test {
         &flags::COLOUR_SCALE,
     ];
 
+    #[allow(unused_macro_rules)]
     macro_rules! test {
         ($name:ident:  $type:ident <- $inputs:expr;  $stricts:expr => $result:expr) => {
             #[test]
@@ -203,14 +219,4 @@ mod terminal_test {
     test!(overridden_6:  UseColours <- ["--color=auto",  "--colour=never"], MockVars::empty();  Complain => err OptionsError::Duplicate(Flag::Long("color"),  Flag::Long("colour")));
     test!(overridden_7:  UseColours <- ["--colour=auto", "--color=never"], MockVars::empty();   Complain => err OptionsError::Duplicate(Flag::Long("colour"), Flag::Long("color")));
     test!(overridden_8:  UseColours <- ["--color=auto",  "--color=never"], MockVars::empty();   Complain => err OptionsError::Duplicate(Flag::Long("color"),  Flag::Long("color")));
-
-    test!(scale_1:  ColourScale <- ["--color-scale", "--colour-scale"];   Last => Ok(ColourScale::Gradient));
-    test!(scale_2:  ColourScale <- ["--color-scale",                 ];   Last => Ok(ColourScale::Gradient));
-    test!(scale_3:  ColourScale <- [                 "--colour-scale"];   Last => Ok(ColourScale::Gradient));
-    test!(scale_4:  ColourScale <- [                                 ];   Last => Ok(ColourScale::Fixed));
-
-    test!(scale_5:  ColourScale <- ["--color-scale", "--colour-scale"];   Complain => err OptionsError::Duplicate(Flag::Long("color-scale"),  Flag::Long("colour-scale")));
-    test!(scale_6:  ColourScale <- ["--color-scale",                 ];   Complain => Ok(ColourScale::Gradient));
-    test!(scale_7:  ColourScale <- [                 "--colour-scale"];   Complain => Ok(ColourScale::Gradient));
-    test!(scale_8:  ColourScale <- [                                 ];   Complain => Ok(ColourScale::Fixed));
 }
