@@ -15,14 +15,20 @@ fn cli_windows_tests() {
     trycmd::TestCases::new().case("tests/cmd/*_windows.toml");
 }
 
-#[test]
-#[cfg(feature = "nix")]
-fn cli_nix_tests() {
-    trycmd::TestCases::new().case("tests/cmd/*_nix.toml");
-}
-
 #[test]
 #[cfg(feature = "nix-local")]
 fn cli_nix_local_tests() {
     trycmd::TestCases::new().case("tests/cmd/*_nix_local.toml");
 }
+
+#[test]
+#[cfg(feature = "powertest")]
+fn cli_powertest_tests() {
+    trycmd::TestCases::new().case("tests/ptests/*.toml");
+}
+
+#[test]
+#[cfg(feature = "nix")]
+fn cli_nix_generated_tests() {
+    trycmd::TestCases::new().case("tests/gen/*.toml");
+}
